@@ -4,6 +4,9 @@
 # Licence GPL v3
 
 
+
+
+
 .readRowsNetCDF <- function(x, row, nrows=1, col=1, ncols=(ncol(x)-col+1)) {
 
 	if ( x@file@toptobottom ) { 
@@ -22,8 +25,25 @@
 	}
 	
 	zvar <- x@data@zvar
-		
-	if (nc$var[[zvar]]$ndims == 2) {
+
+	if (nc$var[[zvar]]$ndims == 1) {
+		# for GMT
+		ncx <- ncol(x)
+		start <- (row-1) * ncx + 1
+		count <- nrows * ncx 
+		if (ncdf4) {
+			d <- ncdf4::ncvar_get( nc, varid=zvar,  start=start, count=count )		
+		} else {
+			d <- get.var.ncdf( nc,  varid=zvar,  start=start, count=count )
+		}
+		if (col > 1 | ncols < ncx) {
+			d <- matrix(d, ncol=ncx, byrow=TRUE)
+			d <- d[, col:(col+ncols-1)]
+			d <- as.vector(t(d))
+		}
+
+	
+	} else if (nc$var[[zvar]]$ndims == 2) {
 		start <- c(col, row)
 		count <- c(ncols, nrows)
 		if (ncdf4) {
