@@ -1,11 +1,11 @@
-# Author: Robert J. Hijmans, r.hijmans@gmail.com
+# Author: Robert J. Hijmans
 # Date :  January 2009
 # Version 0.9
 # Licence GPL v3
 
 
-
 'projection<-' <- function(x, value) {
+
 	if (class(value)=="CRS") {
 		crs <- value
 	} else {	
@@ -19,20 +19,36 @@
 			}
 		}
 	} 
+	
 	if (inherits(x, 'Spatial')) {
 		x@proj4string <- crs
 	} else {
-		x@crs = crs
+		x@crs <- crs
 	}
 	return(x)
+	
 }
 
 
 projection <- function(x, asText=TRUE) {
-	if (extends(class(x), "BasicRaster")) { x <- x@crs 
-	} else if (extends(class(x), "Spatial")) { x <- x@proj4string 
-	} else if (class(x) == 'character') {return(x)
-	} else if (class(x) != "CRS") { if (asText) { return("NA") } else { return(NA) }  }
+
+	if (extends(class(x), "BasicRaster")) { 
+		x <- x@crs 
+	} else if (extends(class(x), "Spatial")) { 
+		x <- x@proj4string
+	} else if (class(x) == 'character') { 
+		if (asText) {
+			return(x)
+		} else {
+			return( CRS(x) )
+		}
+	} else if (class(x) != "CRS") { 
+		if (asText) { 
+			return("NA")
+		} else { 
+			return(NA) 
+		}  
+	}
 	
 	if (asText) {
 		if (is.na(x@projargs)) { 
@@ -47,6 +63,7 @@ projection <- function(x, asText=TRUE) {
 
 
 setMethod("proj4string", signature('Raster'), 
+# redundant, for compatibility with sp
 	function(obj) {
 		projection(obj)
 	}
@@ -54,10 +71,10 @@ setMethod("proj4string", signature('Raster'),
 
 
 setMethod("proj4string<-", signature('Raster'), 
+# redundant, for compatibility with sp
 	function(obj, value) {
 		projection(obj) <- value
 		obj
 	}
 )
 
-
